<?xml version="1.0" encoding="UTF-8" ?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
<xsl:output method="xml" indent="yes" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

    <!--Шаблон, преобразующий номер дня недели в его текстовое представление-->
    <xsl:template name="get-day-of-the-week-abbreviation">
      <xsl:param name="day-of-the-week"/>
      <xsl:choose>
        <xsl:when test="$day-of-the-week = 1">Вс</xsl:when>
        <xsl:when test="$day-of-the-week = 2">Пн</xsl:when>
        <xsl:when test="$day-of-the-week = 3">Вт</xsl:when>
        <xsl:when test="$day-of-the-week = 4">Ср</xsl:when>
        <xsl:when test="$day-of-the-week = 5">Чт</xsl:when>
        <xsl:when test="$day-of-the-week = 6">Пт</xsl:when>
        <xsl:when test="$day-of-the-week = 7">Сб</xsl:when>
        <xsl:otherwise>?</xsl:otherwise>
      </xsl:choose>
    </xsl:template>

    <!--Шаблон, преобразующий порядковый номер месяца в его текстовое представление-->
    <xsl:template name="get-month-name">
      <xsl:param name="month"/>
      <xsl:choose>
        <xsl:when test="$month = 1">янв</xsl:when>
        <xsl:when test="$month = 2">фев</xsl:when>
        <xsl:when test="$month = 3">мар</xsl:when>
        <xsl:when test="$month = 4">апр</xsl:when>
        <xsl:when test="$month = 5">май</xsl:when>
        <xsl:when test="$month = 6">июн</xsl:when>
        <xsl:when test="$month = 7">июл</xsl:when>
        <xsl:when test="$month = 8">авг</xsl:when>
        <xsl:when test="$month = 9">сен</xsl:when>
        <xsl:when test="$month = 10">окт</xsl:when>
        <xsl:when test="$month = 11">ноя</xsl:when>
        <xsl:when test="$month = 12">дек</xsl:when>
        <xsl:otherwise>?</xsl:otherwise>
      </xsl:choose>
    </xsl:template>

    <!--Шаблон, показывающий текстовое представление облачности-->
    <xsl:template name="get-cloudiness">
      <xsl:param name="cloudiness"/>
      <xsl:choose>
        <xsl:when test="$cloudiness = 0">ясно</xsl:when>
        <xsl:when test="$cloudiness = 1">малооблачно</xsl:when>
        <xsl:when test="$cloudiness = 2">облачно</xsl:when>
        <xsl:when test="$cloudiness = 3">пасмурно</xsl:when>
        <xsl:otherwise>?</xsl:otherwise>
      </xsl:choose>
    </xsl:template>

    <!--Шаблон, показывающий текстовое представление атмосферных явлений-->
    <xsl:template name="get-precipitation">
      <xsl:param name="precipitation"/>
      <xsl:choose>
        <xsl:when test="$precipitation = 4">дождь</xsl:when>
        <xsl:when test="$precipitation = 5">ливень</xsl:when>
        <xsl:when test="$precipitation = 6">снег</xsl:when>
        <xsl:when test="$precipitation = 7">снег</xsl:when>
        <xsl:when test="$precipitation = 8">гроза</xsl:when>
        <xsl:when test="$precipitation = 10">без осадков</xsl:when>
        <xsl:otherwise>?</xsl:otherwise>
      </xsl:choose>
    </xsl:template>

    <!--Корневой шаблн результирующей страницы-->
    <xsl:template match="/">
        <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <title>gis meteo informer</title>
                <style type="text/css"></style>
            </head>
            <body>
             <!--Здесь мы выбираем только самый первый(ближайший) прогноз под номером 1 -->
              <xsl:apply-templates select="MMWEATHER/*/TOWN/FORECAST[1]"/>
            </body>
        </html>
    </xsl:template>

    <!--Базовый шаблон, отображающий информер-->
    <xsl:template match="MMWEATHER/*/TOWN/FORECAST">
        <div id="informer0">
          <table cellspacing="0" cellpadding="1" width="100%" border="0" class="gmtbl" id="gmtbl5">
            <tr>
              <td width="100%" colspan="3">
                <table cellspacing="0" cellpadding="0" width="100%">
                  <tr>
                    <td height="20" width="100%" class="gmtdttl" id="gmtdttl5" colspan="3">
                      <b><a target="_blank" class="gmtdttl" id="tgmtdttl5" href="http://www.gismeteo.RU/city/daily/4368">Москва</a></b>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
            <tr>
              <td width="15%">
                <!--Здесь вставляем шаблон, отображающий атмосферные явления-->
                <xsl:apply-templates select="PHENOMENA"/>
              </td>
              <td width="85%" class="gmtdtext" id="tgmtdtext50">
                <xsl:value-of select="@day"/>
                <!--Далее идет вызов шаблонов, отображающих дату в удобном формате-->
                <xsl:call-template name="get-month-name">
                  <xsl:with-param name="month" select="@month" />
                </xsl:call-template> - <xsl:call-template name="get-day-of-the-week-abbreviation">
                  <xsl:with-param name="day-of-the-week" select="@weekday" />
                </xsl:call-template><br/>
                <!--Здесь вставляем шаблон, отображающий температуру-->
                <b><xsl:apply-templates select="TEMPERATURE"/></b><br/>
                <a target="_blank" class="gmtdtext" id="lgmtdtext50" href="http://www.gismeteo.RU">GISMETEO.RU</a>
              </td>
            </tr>
            <tr>
              <td colspan="3" heigth="5"/>
            </tr>
          </table>
        </div>
    </xsl:template>

    <!--Шаблон, отображающий температуру-->
    <xsl:template match="TEMPERATURE">
        <xsl:value-of select="@min"/>..<xsl:value-of select="@max"/> °C
    </xsl:template>

    <!--Шаблон, отображающий атмосферные явления-->
    <xsl:template match="PHENOMENA">
        <xsl:element name="img">
          <xsl:attribute name="height">60</xsl:attribute>
          <xsl:attribute name="width">59</xsl:attribute>
          <xsl:attribute name="alt">
            <xsl:call-template name="get-cloudiness">
              <xsl:with-param name="cloudiness" select="@cloudiness" />
            </xsl:call-template>,
            <xsl:call-template name="get-precipitation">
              <xsl:with-param name="precipitation" select="@precipitation" />
            </xsl:call-template>
          </xsl:attribute>
          <xsl:attribute name="src">http://informer.gismeteo.ru/getcode/html/images/animbg/<xsl:value-of select="@cloudiness"/>.gif</xsl:attribute>
        </xsl:element>
    </xsl:template>

</xsl:stylesheet>

